import { world, system, BlockPermutation, GameMode } from "@minecraft/server";

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  initEvent.itemComponentRegistry.registerCustomComponent("nicothekid:powder_staff_on_hit_entity", {
    onHitEntity: eventData => {
      const damager = eventData.attackingEntity;
      const target = eventData.hitEntity;
      const itemUsed = eventData.itemStack;
      const { x, y, z } = target.location;
      const damagerEquippable = damager.getComponent("equippable");
      if (itemUsed.typeId === "nicothekid:powder_staff") {
        const itemEnchantable = itemUsed.getComponent("enchantable");
        const unbreakingLevel = itemEnchantable?.getEnchantment("unbreaking")?.level ?? 0;
        const breakChance = 100 / (unbreakingLevel + 1);
        const randomizeChance = Math.random() * 100;
        if (breakChance < randomizeChance) return;
        const itemDurability = itemUsed.getComponent("durability");
        if (!itemDurability) return;
        const itemMaxDurability = itemDurability.maxDurability;
        const itemDurabilityDamage = itemDurability.damage;
        const durabilityCalculation = itemMaxDurability - itemDurabilityDamage;
        let damageAmount = 0;
        if (damager.typeId === "minecraft:player") {
          if (!damager.matches({ gameMode: GameMode.creative })) {
            damageAmount = 2;
          }
          else return;
        }
        else {
          damageAmount = 1;
        };
        const currentDurability = durabilityCalculation - damageAmount;
        if (currentDurability <= 0) {
          damager.dimension.playSound("random.break", damager.location, { pitch: 0.9, volume: 1.0 });
          if (damager.typeId === "minecraft:player") {
            damagerEquippable.setEquipment("Mainhand", null);
          }
        }
        else {
          itemDurability.damage += damageAmount;
          if (damager.typeId === "minecraft:player") {
            damagerEquippable.setEquipment("Mainhand", itemUsed)
          }
        }
      }
      else return;
    }
  });
  initEvent.itemComponentRegistry.registerCustomComponent("nicothekid:powder_staff_on_use", {
    onUse: eventData => {
      const player = eventData.source;
      const itemUsed = eventData.itemStack;
      const playerEquippable = player.getComponent("equippable");
      function damageDurability () {
        if (!player.matches({ gameMode: GameMode.creative })) {
          const itemEnchantable = itemUsed.getComponent("minecraft:enchantable");
          const unbreakingLevel = itemEnchantable?.getEnchantment("unbreaking")?.level ?? 0;
          const breakChance = 100 / (unbreakingLevel + 1);
          const randomizeChance = Math.random() * 100;
          if (breakChance < randomizeChance) return;
          const itemDurability = itemUsed.getComponent("durability");
          if (!itemDurability) return;
          const itemMaxDurability = itemDurability.maxDurability;
          const itemDurabilityDamage = itemDurability.damage;
          const durabilityCalculation = itemMaxDurability - itemDurabilityDamage;
          let damageAmount = 1;
          const currentDurability = durabilityCalculation - damageAmount;
          if (currentDurability <= 0) {
            player.playSound("random.break", { pitch: 0.9, location: player.location, volume: 1 });
            playerEquippable.setEquipment("Mainhand", null);
          }
          else {
            itemDurability.damage += damageAmount;
            playerEquippable.setEquipment("Mainhand", itemUsed)
          }
        }
      }
      if (itemUsed.typeId === "nicothekid:powder_staff") {
        const cooldown = itemUsed.getComponent("cooldown").getCooldownTicksRemaining(player);
        const offhandItem = playerEquippable.getEquipment("Offhand");
        const customPowder = [
          "nicothekid:amethyst_powder",
          "nicothekid:charcoal_powder",
          "nicothekid:cocoa_powder",
          "nicothekid:diamond_powder",
          "nicothekid:emerald_powder",
          "nicothekid:enchanted_dust",
          "nicothekid:gold_powder",
          "nicothekid:iron_powder",
          "nicothekid:lapis_lazuli_powder",
          "nicothekid:netherite_powder"
        ]
        if (offhandItem === undefined || !customPowder.includes(offhandItem.typeId)) {
          if (cooldown == 43) {
            player.playSound("game.player.attack.nodamage", { pitch: 1.1, location: player.location, volume: 1.0 });
            player.runCommandAsync(`tellraw @p {\"rawtext\":[{\"text\":\"§eYou don't have any powder materials in your off-hand to use as a projectile.§r\"}]}`);
            system.runTimeout(() => {
              player.startItemCooldown("powder_staff", 0 );
              return;
            }, 5);
          }
          else return;
        }
        else if (customPowder.includes(offhandItem.typeId)) {
          if (cooldown == 43) {
            player.playSound("mob.shulker.shoot", { pitch: 1.5, location: player.location, volume: 1.0 });
            player.playAnimation("attack");
          }
          else return;
        }
        else return;
      }
      else return;
    }
  });
});