import { world, system, BlockPermutation, GameMode } from "@minecraft/server";

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  initEvent.itemComponentRegistry.registerCustomComponent("nicothekid:staff_of_the_sea_on_hit_entity", {
    onHitEntity: eventData => {
      const damager = eventData.attackingEntity;
      const target = eventData.hitEntity;
      const itemUsed = eventData.itemStack;
      const { x, y, z } = target.location;
      const damagerEquippable = damager.getComponent("equippable");
      if (itemUsed.typeId === "nicothekid:staff_of_the_sea") {
        const pitchRange = Math.random() * (2.4 - 0.8) + 0.8;
        if (!target.matches({ excludeFamilies:[ "blaze", "magmacube", "strider", "enderman", "fire_bird", "soul_fire_bird", "magma_golem", "nether_wisp", "nether_soul_wisp" ] })) {
          if (target.typeId === "minecraft:magma_cube" || target.typeId === "nicothekid:magma_golem") {
            target.applyDamage( 2, { cause: "override", damagingEntity: damager });
            target.applyKnockback( x, z, 0.0, 0.0 );
            damager.dimension.playSound("random.fizz", damager.location, { pitch: pitchRange, volume: 0.7 });
          }
          else if (target.typeId === "minecraft:strider" || target.typeId === "minecraft:enderman") {
            target.applyDamage( 2, { cause: "override", damagingEntity: damager });
            target.applyKnockback( x, z, 0.0, 0.0 );
          }
          else {
            target.applyDamage( 3, { cause: "override", damagingEntity: damager });
            target.applyKnockback( x, z, 0.0, 0.0 );
            damager.dimension.playSound("random.fizz", damager.location, { pitch: pitchRange, volume: 0.7 });
          }
        }
        if (target.hasComponent("minecraft:onfire")) {
          target.extinguishFire( true );
          damager.dimension.playSound("random.fizz", damager.location, { pitch: pitchRange, volume: 0.8 });
        }
        const itemEnchantable = itemUsed.getComponent("enchantable");
        const unbreakingLevel = itemEnchantable?.getEnchantment("unbreaking")?.level ?? 0;
        const breakChance = 100 / (unbreakingLevel + 1);
        const randomizeChance = Math.random() * 100;
        if (breakChance < randomizeChance) return;
        const itemDurability = itemUsed.getComponent("durability");
        if (!itemDurability) return;
        const itemMaxDurability = itemDurability.maxDurability;
        const itemDurabilityDamage = itemDurability.damage;
        const durabilityCalculation = itemMaxDurability - itemDurabilityDamage;
        let damageAmount = 0;
        if (damager.typeId === "minecraft:player") {
          if (!damager.matches({ gameMode: GameMode.creative })) {
            damageAmount = 3;
          }
          else return;
        }
        else {
          damageAmount = 2;
        };
        const currentDurability = durabilityCalculation - damageAmount;
        if (currentDurability <= 0) {
          damager.dimension.playSound("random.break", damager.location, { pitch: 0.9, volume: 1.0 });
          if (damager.typeId === "minecraft:player") {
            damagerEquippable.setEquipment("Mainhand", null);
          }
        }
        else {
          itemDurability.damage += damageAmount;
          if (damager.typeId === "minecraft:player") {
            damagerEquippable.setEquipment("Mainhand", itemUsed)
          }
        }
      }
      else return;
    }
  });
  initEvent.itemComponentRegistry.registerCustomComponent("nicothekid:staff_of_the_sea_on_use", {
    onUse: eventData => {
      const player = eventData.source;
      const itemUsed = eventData.itemStack;
      const playerEquippable = player.getComponent("equippable");
      function damageDurability () {
        if (!player.matches({ gameMode: GameMode.creative })) {
          const itemEnchantable = itemUsed.getComponent("minecraft:enchantable");
          const unbreakingLevel = itemEnchantable?.getEnchantment("unbreaking")?.level ?? 0;
          const breakChance = 100 / (unbreakingLevel + 1);
          const randomizeChance = Math.random() * 100;
          if (breakChance < randomizeChance) return;
          const itemDurability = itemUsed.getComponent("durability");
          if (!itemDurability) return;
          const itemMaxDurability = itemDurability.maxDurability;
          const itemDurabilityDamage = itemDurability.damage;
          const durabilityCalculation = itemMaxDurability - itemDurabilityDamage;
          let damageAmount = 1;
          const currentDurability = durabilityCalculation - damageAmount;
          if (currentDurability <= 0) {
            player.playSound("random.break", { pitch: 0.9, location: player.location, volume: 1 });
            playerEquippable.setEquipment("Mainhand", null);
          }
          else {
            itemDurability.damage += damageAmount;
            playerEquippable.setEquipment("Mainhand", itemUsed)
          }
        }
      }
      if (itemUsed.typeId === "nicothekid:staff_of_the_sea") {
        const cooldown = itemUsed.getComponent("cooldown").getCooldownTicksRemaining(player);
        const playerOnBlock = player.dimension.getBlock({ x: player.location.x, y: player.location.y + 0.5, z: player.location.z });
        const validWater = [
          "minecraft:flowing_water",
          "minecraft:water"
        ]
        if (!validWater.includes(playerOnBlock.typeId)) {
          if (cooldown == 799) {
            player.playSound("game.player.attack.nodamage", { pitch: 1.1, location: player.location, volume: 1.0 });
            player.runCommandAsync(`tellraw @p {\"rawtext\":[{\"text\":\"§eYou have to be in water to activate the staff's effect§r\"}]}`);
            system.runTimeout(() => {
              player.startItemCooldown("staff_of_the_sea", 0 );
              return;
            }, 10);
          }
          else return;
        }
        else if (validWater.includes(playerOnBlock.typeId) && cooldown == 799) {
          if (cooldown == 799) {
            player.addEffect("conduit_power", 1800, {amplifier: 0, showParticles: false })
            player.playSound("conduit.activate", { pitch: 1.1, location: player.location, volume: 1.0 });
            player.playAnimation("attack");
            player.dimension.spawnParticle("nicothekid:staff_of_the_sea_activation_particle", { x: player.location.x, y: player.location.y + 0.5, z: player.location.z });
            damageDurability ();
          }
          else return;
        }
        else return;
      }
      else return;
    }
  });
});